==> cargo-binstall-1.15.5-1.src.tar.gz: cargo-binstall-1.15.5/crates/binstalk-types/CHANGELOG.md <==
# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.10.0](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-types-v0.9.4...binstalk-types-v0.10.0) - 2025-06-06

### Fixed

- fix updating of installed crates manifest on custom sparse registry ([#2178](https://github.com/cargo-bins/cargo-binstall/pull/2178))

## [0.9.4](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-types-v0.9.3...binstalk-types-v0.9.4) - 2025-03-07

### Other

- *(deps)* bump the deps group with 3 updates ([#2072](https://github.com/cargo-bins/cargo-binstall/pull/2072))

## [0.9.3](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-types-v0.9.2...binstalk-types-v0.9.3) - 2025-02-11

### Other

- *(deps)* bump the deps group with 2 updates (#2044)

## [0.9.2](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-types-v0.9.1...binstalk-types-v0.9.2) - 2024-11-23

### Other

- *(deps)* bump the deps group with 2 updates ([#1981](https://github.com/cargo-bins/cargo-binstall/pull/1981))

## [0.9.1](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-types-v0.9.0...binstalk-types-v0.9.1) - 2024-11-05

### Other

- *(deps)* bump the deps group with 3 updates ([#1954](https://github.com/cargo-bins/cargo-binstall/pull/1954))

## [0.9.0](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-types-v0.8.0...binstalk-types-v0.9.0) - 2024-08-10

### Added
- Merge disable strategies ([#1868](https://github.com/cargo-bins/cargo-binstall/pull/1868))

==> cargo-binstall-1.15.10-1.src.tar.gz: cargo-binstall-1.15.10/crates/binstalk-types/CHANGELOG.md <==
# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.10.1](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-types-v0.10.0...binstalk-types-v0.10.1) - 2025-10-24

### Other

- *(lints)* introduce typos-cli config in `Cargo.toml` and handle typos ([#2337](https://github.com/cargo-bins/cargo-binstall/pull/2337))

## [0.10.0](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-types-v0.9.4...binstalk-types-v0.10.0) - 2025-06-06

### Fixed

- fix updating of installed crates manifest on custom sparse registry ([#2178](https://github.com/cargo-bins/cargo-binstall/pull/2178))

## [0.9.4](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-types-v0.9.3...binstalk-types-v0.9.4) - 2025-03-07

### Other

- *(deps)* bump the deps group with 3 updates ([#2072](https://github.com/cargo-bins/cargo-binstall/pull/2072))

## [0.9.3](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-types-v0.9.2...binstalk-types-v0.9.3) - 2025-02-11

### Other

- *(deps)* bump the deps group with 2 updates (#2044)

## [0.9.2](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-types-v0.9.1...binstalk-types-v0.9.2) - 2024-11-23

### Other

- *(deps)* bump the deps group with 2 updates ([#1981](https://github.com/cargo-bins/cargo-binstall/pull/1981))

## [0.9.1](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-types-v0.9.0...binstalk-types-v0.9.1) - 2024-11-05

### Other

- *(deps)* bump the deps group with 3 updates ([#1954](https://github.com/cargo-bins/cargo-binstall/pull/1954))

## [0.9.0](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-types-v0.8.0...binstalk-types-v0.9.0) - 2024-08-10

### Added
- Merge disable strategies ([#1868](https://github.com/cargo-bins/cargo-binstall/pull/1868))
